pub enum Role {
System,
Assistant,
User,
}Expand description
A role of a message sender, can be:
System, for starting system message, that sets the tone of modelAssistant, for messages sent by ChatGPTUser, for messages sent by user
Variants
System
A system message, automatically sent at the start to set the tone of the model
Assistant
A message sent by ChatGPT
User
A message sent by the user