pub struct CompletionResponse {
pub message_id: String,
pub created_timestamp: u64,
pub model: String,
pub usage: TokenUsage,
pub message_choices: Vec<MessageChoice>,
}Expand description
A response struct received from the API after requesting a message completion
Fields
message_id: StringUnique ID of the message, but not in a UUID format.
Example: chatcmpl-6p5FEv1JHictSSnDZsGU4KvbuBsbu
created_timestamp: u64Unix seconds timestamp of when the response was created
model: StringThe model that was used for this completion
usage: TokenUsageToken usage of this completion
message_choices: Vec<MessageChoice>Message choices for this response, guaranteed to contain at least one message response
Implementations
Sourceimpl CompletionResponse
impl CompletionResponse
Sourcepub fn message(&self) -> &ChatMessage
pub fn message(&self) -> &ChatMessage
A shortcut to access the message response